@@ -79,14 +79,13 @@ plotD3.aggregated_profiles_explainer <- function(x, ..., size = 2, alpha = 1,
   is_x_numeric <- is.numeric(aggregated_profiles$`_x_`)
 
   # prepare profiles data
-  aggregated_profiles$`_vname_` <- droplevels(aggregated_profiles$`_vname_`)
   rownames(aggregated_profiles) <- NULL
 
   ymax <- max(aggregated_profiles$`_yhat_`)
   ymin <- min(aggregated_profiles$`_yhat_`)
   ymargin <- abs(ymax - ymin)*0.1
 
-  aggregated_profiles_list <- split(aggregated_profiles, aggregated_profiles$`_vname_`)
+  aggregated_profiles_list <- split(aggregated_profiles, aggregated_profiles$`_vname_`, drop = TRUE)
 
   min_max_list <- ymean <- label_names <- NULL
 
